@@ -16,7 +16,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id: CiscoIOS.pm,v 1.8 2010/12/02 19:38:29 evertonm Exp $
+# $Id: CiscoIOS.pm,v 1.1 2006/06/08 20:28:39 evertonm Exp $
 
 package fetchconfig::model::CiscoIOS; # fetchconfig/model/CiscoIOS.pm
 
@@ -59,14 +59,9 @@ sub chat_login {
     my ($self, $t, $dev_id, $dev_host, $dev_opt_tab) = @_;
     my $ok;
 
-    my $login_prompt = '/(Username:|Password:) $/';
-
-    # chat_banner is used to allow temporary modification
-    # of timeout throught the 'banner_timeout' option
-
-    my ($prematch, $match) = $self->chat_banner($t, $dev_opt_tab, $login_prompt);
+    my ($prematch, $match) = $t->waitfor(Match => '/(Username:|Password:) $/');
     if (!defined($prematch)) {
-	$self->log_error("could not find login prompt: $login_prompt");
+	$self->log_error("could not find login prompt");
 	return undef;
     }
 
@@ -153,7 +148,7 @@ sub chat_login {
     }
 
     if ($match !~ /^(\S+)\#$/) {
-	$self->log_error("could not match enable command prompt");
+	$self->log_error("could not find enable command prompt");
 	return undef;
     }
 
@@ -185,7 +180,7 @@ sub expect_enable_prompt {
 }
 
 sub chat_fetch {
-    my ($self, $t, $dev_id, $dev_host, $prompt, $fetch_timeout, $show_cmd, $conf_ref) = @_;
+    my ($self, $t, $dev_id, $dev_host, $prompt, $conf_ref) = @_;
     my $ok;
     
     $ok = $t->print('term len 0');
@@ -197,60 +192,25 @@ sub chat_fetch {
     my ($prematch, $match) = $self->expect_enable_prompt($t, $prompt);
     return unless defined($prematch);
 
-    # Backward compatibility support for option "show_cmd=wrterm"
-    my $custom_cmd;
-    if (defined($show_cmd)) {
-	$custom_cmd = ($show_cmd eq 'wrterm') ? 'write term' : $show_cmd;
-    }
-
-    if ($self->chat_show_conf($t, 'show run', $custom_cmd)) {
+    $ok = $t->print('sh run');
+    if (!$ok) {
+	$self->log_error("could not send show running command");
 	return 1;
     }
 
-	# Prevent "show run" command from appearing in config dump
-	$t->getline();
-
-	# Commment out garbage at top so config file can be restored
-	# cleanly at a later date
-	my($line,$top_info);
-	while($line=$t->getline()) {
-		# Failsafe: Just in case 'Current configuration'
-		# doesn't appear, assume config begins with 'version'
-		# or first valid comment.
-		if($line=~/^version / || $line=~/^\!/) {
-			$top_info.=$line;
-			last;
-		} else {
-			$top_info.='!!' . $line;
-		}
-		# Normally, finding the "Current configuration" line
-		# will be enough to exit this loop.
-		last if $line=~/^Current configuration/;
-	}
-
-    my $save_timeout;
-    if (defined($fetch_timeout)) {
-        $save_timeout = $t->timeout;
-        $t->timeout($fetch_timeout);
-    }
-
     ($prematch, $match) = $self->expect_enable_prompt($t, $prompt);
     if (!defined($prematch)) {
 	$self->log_error("could not find end of configuration");
 	return 1;
     }
 
-    if (defined($fetch_timeout)) {
-        $t->timeout($save_timeout);
-    }
-
     $self->log_debug("found end of configuration: [$match]");
 
-    @$conf_ref = split /\n/, $top_info . $prematch;
+    @$conf_ref = split /\n/, $prematch;
 
     $self->log_debug("fetched: " . scalar @$conf_ref . " lines");
 
-    undef;
+    return undef;
 }
 
 sub do_fetch {
@@ -292,11 +252,7 @@ sub do_fetch {
 
     my @config;
 
-    my $fetch_timeout = $self->dev_option($dev_opt_tab, "fetch_timeout");
-
-    my $show_cmd = $self->dev_option($dev_opt_tab, "show_cmd");
-
-    return if $self->chat_fetch($t, $dev_id, $dev_host, $prompt, $fetch_timeout, $show_cmd, \@config);
+    return if $self->chat_fetch($t, $dev_id, $dev_host, $prompt, \@config);
 
     $ok = $t->close;
     if (!$ok) {
